@@ -7,7 +7,7 @@ use PDF::API2;
 
 use 5.008002;
 
-our $VERSION = '1.0.0.2';
+our $VERSION = '1.0.0.4';
 
 use constant PI => 4 * atan2(1, 1);
 
@@ -541,24 +541,24 @@ sub _getImageObject{
     my ($self,$imagePath,$ext) = @_;   
     
     my $PDF = $self->getPDF;
-    if ($ext eq 'tiff'){
+    if ($ext && $ext eq 'tiff'){
         return $PDF->image_tiff($imagePath);
     }
-    elsif ($ext eq 'jpg' || $ext eq 'jpeg'){
+    elsif ($ext && $ext eq 'jpg' || $ext eq 'jpeg'){
         return $PDF->image_jpeg($imagePath);
     }
-    elsif ($ext eq 'png'){
+    elsif ($ext && $ext eq 'png'){
         return $PDF->image_png($imagePath);
     }
-    elsif ($ext eq 'pnm'){
+    elsif ($ext && $ext eq 'pnm'){
         return $PDF->image_pnm($imagePath);
     }
-    elsif ($ext eq 'gif'){
+    elsif ($ext && $ext eq 'gif'){
         return $PDF->image_gif($imagePath);
     }
     else
     {
-        return $PDF->image_gd($imagePath) ;
+        return $PDF->image_gd($imagePath, -lossless => 1) ;
     }
 }
 
